$file: "" !default;

/*!
 * CoreUI #{$file} v5.6.1 (https://coreui.io)
 * Copyright (c) 2026 creativeLabs Łukasz Holeczek
 * Licensed under MIT (https://github.com/coreui/coreui/blob/main/LICENSE)
 */
